use std::sync::Arc;

use axum::extract::State;
use maud::{html, Markup, DOCTYPE};

use crate::{
    clock,
    data::{self, CombinedFish},
    AppState,
};

pub fn layout(content: Markup) -> Markup {
    html! {
        (DOCTYPE)
        html {
            head {
                title { "beacon" }
                meta name="viewport" content="width=device-width";
                link rel="stylesheet" href="/static/style.css";
            }

            body { (content) }
        }
    }
}

pub fn main_page(state: State<Arc<AppState>>) -> Markup {
    let meta = state.data.fish_with_meta();
    let mut values: Vec<&CombinedFish> = meta.values().filter(|f| f.entry.big_fish).collect();
    values.sort_by(|afish, bfish| bfish.is_up.cmp(&afish.is_up));
    layout(html! {
        h1 { "Hello! Current ET " (clock::get_current_eorzea_date().format("%H:%M")) }
        @for fish in values {
            li {
                @if fish.is_up {
                    "Up! "
                } @else {
                   "Next uptime " (fish.next_uptime)
                }
                (fish.meta.name_en)
                details {
                    @if fish.entry.start_hour.is_some() && fish.entry.end_hour.is_some() {
                        "From " (fish.entry.start_hour.unwrap()) "h to " (fish.entry.end_hour.unwrap()) "h"
                    }
                    @if fish.entry.weather_set.len() > 0 {
                        " Weather(s) " (fish.entry.weather_set.iter().map(|i| i.to_string()).collect::<Vec<_>>().join(", "))
                    }
                    @if let Some(forecast) = fish.get_forecast(&state.data) {
                        "Current weather in " (data::get_zone_name(&state.data, forecast.zone_id)) ": " (data::get_weather_name(&state.data, forecast.weather_now().weather_id))
                    }
                }
            }
        }
    })
}
